@@ -8,8 +8,20 @@ class Notification(InstaBaseObject):
         self.from_user = from_user
         self.timestamp = timestamp
 
-    def __repr__(self) -> str:
+    def __str__(self) -> str:
         return f'Notification<{self.type}, {self.from_user}>'
 
+    def __lt__(self, o) -> bool:
+        if self.timestamp < o.timestamp:
+            return True
+        else:
+            return False
+
+    def __gt__(self, o) -> bool:
+        if self.timestamp > o.timestamp:
+            return True
+        else:
+            return False
+
     def get_timestamp(self):
         return self.timestamp
