@@ -101,10 +101,10 @@ class InstaClient(NotificationScraper, TagScraper):
                 discard = kwargs.get('discard_driver')
                 if discard is not None:
                     if discard:
-                        self.__discard_driver()
+                        self.discard_driver()
                 elif len(args) > 0 and isinstance(args[-1], bool):
                     if args[-1]:
-                        self.__discard_driver()
+                        self.discard_driver()
                 
                 time.sleep(random.randint(1, 2))
                 if error:
@@ -255,7 +255,7 @@ class InstaClient(NotificationScraper, TagScraper):
 
         # Discard Driver or complete login
         if discard_driver:
-            self.__discard_driver()
+            self.discard_driver()
         else:
             # Detect and dismiss save info Dialog
             self.driver.get(ClientUrls.HOME_URL)
@@ -503,15 +503,24 @@ class InstaClient(NotificationScraper, TagScraper):
     @__manage_driver()
     def unfollow_user(self, user:str, nav_to_user=True, check_user=True, discard_driver:bool=False):
         """
-        Unfollows user(s)
+        Unfollows a given user.
 
         Args:
-            user:str: Username of user to unfollow
+            user (str): User to unfollow
+            nav_to_user (bool, optional): Navigate to user profile page. Defaults to True.
+            check_user (bool, optional): Check user vadility. Defaults to True.
+            discard_driver (bool, optional): Discard driver when completed. Defaults to False.
+
+        Raises:
+            InvalidUserError: raised if the user specified by the `user` argument is invalid.
         """
         if nav_to_user:
             self.nav_user(user, check_user)
         elif check_user:
-            self.is_valid_user(user, nav_to_user=False)
+            try:
+                self.is_valid_user(user, nav_to_user=False)
+            except PrivateAccountError:
+                pass
             self.logger.debug('INSTACLIENT: User <{}> is valid'.format(user))
 
         if self.__check_existence(EC.presence_of_element_located((By.XPATH, Paths.UNFOLLOW_BTN))):
@@ -521,7 +530,10 @@ class InstaClient(NotificationScraper, TagScraper):
             confirm_unfollow = self.__find_element(EC.presence_of_element_located((By.XPATH, Paths.CONFIRM_UNFOLLOW_BTN)))
             self.__press_button(confirm_unfollow)
             self.logger.debug('INSTACLIENT: Unfollowed user <{}>'.format(user))
-
+        elif self.__check_existence(EC.presence_of_element_located((By.XPATH, Paths.REQUESTED_BTN))):
+            requested_btn = self.__find_element(EC.presence_of_element_located((By.XPATH, Paths.REQUESTED_BTN)))
+            self.__press_button(requested_btn)
+            self.logger.debug(f'Cancelled Follow Request for user <{user}>')
 
     # USER DATA PRODECURES
     @__manage_driver()
@@ -832,7 +844,7 @@ class InstaClient(NotificationScraper, TagScraper):
 
         
         if discard_driver:
-            self.__discard_driver() """
+            self.discard_driver() """
 
                 
     # NAVIGATION PROCEDURES
@@ -1064,7 +1076,7 @@ class InstaClient(NotificationScraper, TagScraper):
             raise BlockedAccountError(self.username)
 
 
-    def __discard_driver(self):
+    def discard_driver(self):
         self.logger.debug('INSTACLIENT: Discarding driver...')
         if self.driver:
             self.driver.quit()
